==> nextcloud-21.0.6.tgz: nextcloud/apps/survey_client/l10n/zh_TW.js <==
OC.L10N.register(
    "survey_client",
    {
    "Last report sent on: {on}" : "上次傳送回報的時間：{on}",
    "An error occurred while sending your report." : "傳送您的回報時發生錯誤。",
    "App list <em>(for each app: name, version, enabled status)</em>" : "應用程式清單<em>（針對每個應用程式：名稱、版本、啟用狀態）</em>",
    "Database environment <em>(type, version, database size)</em>" : "資料庫環境<em>（類型、版本、資料庫大小）</em>",
    "Encryption information <em>(is it enabled?, what is the default module)</em>" : "加密資訊<em>（是否啟用？預設模組是哪個）</em>",
    "Number of shares <em>(per type and permission setting)</em>" : "分享數量<em>（類型與權限設定）</em>",
    "PHP environment <em>(version, memory limit, max. execution time, max. file size)</em>" : "PHP 環境<em>（版本、記憶體限制、最大執行時間、最大檔案大小）</em>",
    "Server instance details <em>(version, memcache used, status of locking/previews/avatars)</em>" : "伺服器站台詳細資料<em>（版本、是否使用 memcache、鎖定／預覽／大頭照的狀態）</em>",
    "Statistic <em>(number of files, users, storages per type, comments and tags)</em>" : "統計<em>（檔案數量、使用者、每種類型的儲存空間、留言與標籤）</em>",
    "Usage survey" : "使用情況調查",
    "Help improve Nextcloud" : "協助改善 Nextcloud",
    "Do you want to help us to improve Nextcloud by providing some anonymized data about your setup and usage? You can disable it at any time in the admin settings again." : "您想要透過提供一些關於您的設定與使用情況的匿名資料來協助我們改善 Nextcloud 嗎？您隨時可以在管理員設定中再次將其停用。",
    "Not now" : "現在不要",
    "Send usage" : "傳送使用狀況",
    "Never" : "絕不",
    "Sends anonymized data to Nextcloud to help us to improve Nextcloud." : "傳送匿名資料到 Nextcloud 以協助我們改善 Nextcloud。",
    "Sends anonymized data to Nextcloud to help us to improve Nextcloud. You\n        always have full control over the content sent to Nextcloud and can disable\n        it again at any time." : "傳送匿名資料到 Nextcloud 以協助我們改善 Nextcloud。您\n        永遠都有對傳送到 Nextcloud 的資料的完整控制權，且隨時\n        可以將其停用。",
    "You can help improve Nextcloud by sending us some data about your current setup and usage." : "您可以透過傳送一些關於您目前設定與使用情況的資料來協助改善 Nextcloud。",
    "We take your privacy seriously. Sending data is disabled by default, and should you choose to turn it on, it will be anonymized first, and you are given the option of what things to share. Upon receiving a report, the previous one is removed. Upload a clean report to delete all data currently stored on the server" : "我們認真對待您的隱私。預設停用傳送資料，且如果您選擇將其開啟，其將先被匿名化，並有選項可以選擇要分享哪些東西。收到回報後，前一個回報將會被移除。上傳乾淨的回報來刪除目前儲存在伺服器上的所有資料。",
    "Send new report now" : "現在傳送新回報",
    "Send usage survey monthly" : "每月傳送使用情況調查",
    "Data to send" : "要傳送的資料",
    "Last report sent on: %s" : "上次傳送回報的時間：%s",
    "Last report" : "上次回報"
},
"nplurals=1; plural=0;");

==> nextcloud-23.0.8.tgz: nextcloud/apps/survey_client/l10n/zh_TW.js <==
OC.L10N.register(
    "survey_client",
    {
    "Last report sent on: {on}" : "上次傳送回報的時間：{on}",
    "An error occurred while sending your report." : "傳送您的回報時發生錯誤。",
    "App list <em>(for each app: name, version, enabled status)</em>" : "應用程式清單<em>（針對每個應用程式：名稱、版本、啟用狀態）</em>",
    "Database environment <em>(type, version, database size)</em>" : "資料庫環境<em>（類型、版本、資料庫大小）</em>",
    "Encryption information <em>(is it enabled?, what is the default module)</em>" : "加密資訊<em>（是否啟用？預設模組是哪個）</em>",
    "Number of shares <em>(per type and permission setting)</em>" : "分享數量<em>（類型與權限設定）</em>",
    "PHP environment <em>(version, memory limit, max. execution time, max. file size)</em>" : "PHP 環境<em>（版本、記憶體限制、最大執行時間、最大檔案大小）</em>",
    "Server instance details <em>(version, memcache used, status of locking/previews/avatars)</em>" : "伺服器站台詳細資料<em>（版本、是否使用 memcache、鎖定／預覽／大頭照的狀態）</em>",
    "Statistic <em>(number of files, users, storages per type, comments and tags)</em>" : "統計<em>（檔案數量、使用者、每種類型的儲存空間、留言與標籤）</em>",
    "Usage survey" : "使用情況調查",
    "Help improve Nextcloud" : "協助改善 Nextcloud",
    "Do you want to help us to improve Nextcloud by providing some anonymized data about your setup and usage? You can disable it at any time in the admin settings again." : "您想要透過提供一些關於您的設定與使用情況的匿名資料來協助我們改善 Nextcloud 嗎？您隨時可以在管理員設定中再次將其停用。",
    "Not now" : "現在不要",
    "Send usage" : "傳送使用狀況",
    "Never" : "絕不",
    "Sends anonymized data to Nextcloud to help us to improve Nextcloud." : "傳送匿名資料到 Nextcloud 以協助我們改善 Nextcloud。",
    "Sends anonymized data to Nextcloud to help us to improve Nextcloud. You\n\t\talways have full control over the content sent to Nextcloud and can disable\n\t\tit again at any time." : "傳送匿名資料至 Nextcloud 以協助我們改善 Nextcloud。您\n\t\t永遠都有對傳送至 Nextcloud 的資料的完整控制權，且\n\t\t隨時可將其停用。",
    "You can help improve Nextcloud by sending us some data about your current setup and usage." : "您可以透過傳送一些關於您目前設定與使用情況的資料來協助改善 Nextcloud。",
    "We take your privacy seriously. Sending data is disabled by default, and should you choose to turn it on, it will be anonymized first, and you are given the option of what things to share. Upon receiving a report, the previous one is removed. Upload a clean report to delete all data currently stored on the server" : "我們認真對待您的隱私。預設停用傳送資料，且如果您選擇將其開啟，其將先被匿名化，並有選項可以選擇要分享哪些東西。收到回報後，前一個回報將會被移除。上傳乾淨的回報來刪除目前儲存在伺服器上的所有資料。",
    "Send new report now" : "現在傳送新回報",
    "Send usage survey monthly" : "每月傳送使用情況調查",
    "Data to send" : "要傳送的資料",
    "Last report sent on: %s" : "上次傳送回報的時間：%s",
    "Last report" : "上次回報",
    "Sends anonymized data to Nextcloud to help us to improve Nextcloud. You\n        always have full control over the content sent to Nextcloud and can disable\n        it again at any time." : "傳送匿名資料到 Nextcloud 以協助我們改善 Nextcloud。您\n        永遠都有對傳送到 Nextcloud 的資料的完整控制權，且隨時\n        可以將其停用。"
},
"nplurals=1; plural=0;");
